package com.zd.airbottle.service;

import java.util.List;
import java.util.Map;

import com.zd.airbottle.domain.QpBottleStorage;
import com.zd.airbottle.domain.vo.BottleStorageInfoVo;
import com.zd.airbottle.domain.vo.QpBottleStorageRVo;
import com.zd.airbottle.domain.vo.QpBottleStorageVO;
import com.zd.airbottle.domain.vo.report.AirAmount;

/**
 * 气瓶入库Service接口
 *
 * @author zd
 * @date 2022-05-19
 */
public interface IQpBottleStorageService {
    /**
     * 查询气瓶入库
     *
     * @param id 气瓶入库主键
     * @return 气瓶入库
     */
    QpBottleStorageVO selectQpBottleStorageById(Long id);

    /**
     * 查询气瓶入库列表
     *
     * @param bottleStorageVO 气瓶入库
     * @return 气瓶入库集合
     */
    List<QpBottleStorageVO> selectQpBottleStorageList(QpBottleStorageVO bottleStorageVO);

    /**
     * 信息记录-入库记录
     *
     * @param bottleStorageVO 信息记录-入库记录
     * @return 信息记录-入库记录集合
     */
    List<QpBottleStorageVO> selectQpBottleStorageRecordList(QpBottleStorageVO bottleStorageVO);

    /**
     * 新增气瓶入库
     *
     * @param qpBottleStorage 气瓶入库
     * @return 结果
     */
    int insertQpBottleStorage(QpBottleStorageVO qpBottleStorage);

    /**
     * 修改气瓶入库
     *
     * @param qpBottleStorage 气瓶入库
     * @return 结果
     */
    int updateQpBottleStorage(QpBottleStorage qpBottleStorage);

    /**
     * 批量删除气瓶入库
     *
     * @param ids 需要删除的气瓶入库主键集合
     * @return 结果
     */
    int deleteQpBottleStorageByIds(Long[] ids);

    /**
     * 删除气瓶入库信息
     *
     * @param id 气瓶入库主键
     * @return 结果
     */
    int deleteQpBottleStorageById(Long id);

    /**
     * 气体库存统计
     *
     * @param airName 气体名称
     * @return List<AirAmount>
     */
    List<AirAmount> calcStorage(String airName);

    /**
     * 楼栋库存统计
     * @param airName 气体名称
     * @return List<AirAmount>
     */
    List<AirAmount> calcBuildStorage(String airName);

    /**
     * 实验室库存排名统计
     * @param airName 气体名称
     * @return List<AirAmount>
     */
    List<AirAmount> calcLocationStorage(String airName);

    /**
     * 入库表实验室关联查询
     */
    List<QpBottleStorageVO> selectQpBottleStorageByRelationSubject(QpBottleStorageVO qpBottleStorageVO);

    /**
     * 根据主键查询气瓶入库相关信息
     * @param ids 主键集合
     * @return List<QpBottleStorageRVo>
     */
    List<QpBottleStorageRVo> getByIds(List<Long> ids);

    /**
     * 根据主键查询气瓶入库相关信息
     * @param id 主键
     * @return QpBottleStorageRVo
     */
    QpBottleStorageRVo getById(Long id);
    /**
     * 根据电子标签查询气瓶入库相关信息
     * @param electronicTag 电子标签码
     * @return QpBottleStorageRVo
     */
    QpBottleStorageRVo getByElectronicTag(String electronicTag);

    /**
     * 解除绑定
     */
    int bottleStorageUnbind(Long id);

    /**
     * 绑定
     */
    int bottleStorageBinding(QpBottleStorage qpBottleStorage);

    /**
     * 根据对象参数查询入库气瓶信息
     * @param bottleStorage 气瓶参数
     * @return 集合对象
     */
    List<QpBottleStorage> getList(QpBottleStorage bottleStorage);

    /**
     * 根据对象参数查询入库气瓶相关信息
     * @param storageInfoVo 气瓶参数
     * @return 集合对象
     */
    List<BottleStorageInfoVo> getStorageInfoList(BottleStorageInfoVo storageInfoVo);

    /***
     *供应商首页待办事项
     */
    List<QpBottleStorageVO> selectQpTaskListIndex(QpBottleStorageVO storageInfoVo);

    /**
     * 查询入库的气瓶
     * @param bottleStorageVO
     * @return
     * 供应商首页待办事项
     */
    List<QpBottleStorageVO> selectIntoStorageList(QpBottleStorageVO bottleStorageVO);

    /***
     *查询问题气瓶
     * @param bottleStorageVO
     * @return
     */
    List<QpBottleStorageVO> selectStorageListRelation(QpBottleStorageVO bottleStorageVO);

    /**
     * 查询实验室负责人
     * @param subjectId
     * @return
     */
    Map<String,Object> selectSubectDetalsById(Long subjectId);
}
